# -*- coding: utf-8 -*-

from django import forms
from django.conf import settings

from accounts.models import User
from ldapaccounts.models import LdapUser
from django.utils.safestring import mark_safe
from accounts.utils import conflit_associate
from billetterie.utils.forms import ModelFormWithFrozenField


class UserForm(ModelFormWithFrozenField):
    def __init__(self, *args, **kwargs):
        instance = kwargs.get("instance", None)
        super(UserForm, self).__init__(*args, **kwargs)
        if instance is None:
            self.fields["conditions_field"] = forms.BooleanField(
                required=True, label="J'accepte la charte de la billetterie"
            )
        elif (not instance.login_inp_net) and (instance.charte_version is None):
            self.fields["conditions_field"] = forms.BooleanField(
                required=True, label="J'accepte la charte de la billetterie"
            )
        elif (not instance.login_inp_net) and (instance.charte_version < settings.CHARTE_VERSION):
            self.fields["conditions_field"] = forms.BooleanField(
                required=True, label="J'accepte la nouvelle charte de la billetterie"
            )

    class Meta:
        model = User
        fields = ["first_name", "last_name", "email"]


class AssociateForm(forms.Form):
    login_inp_net = forms.CharField(max_length=128, required=True, label="Login INP-net du compte à associer")

    def is_valid(self, user):
        valid = super(AssociateForm, self).is_valid()

        if not valid:
            return valid

        if (
            not LdapUser.objects.filter(login_inp_net=self.cleaned_data["login_inp_net"]).exists()
        ) or conflit_associate(user, LdapUser.objects.get(login_inp_net=self.cleaned_data["login_inp_net"])):
            self.errors["login_inp_net"] = forms.utils.ErrorList(
                [mark_safe("Pas de compte INP-net trouvé pour ce login ou compte déjà existant sur la billetterie")]
            )
            valid = False
        return valid


class PasswordForm(forms.Form):

    password = forms.CharField(max_length=128, required=True, label="Mot de passe", widget=forms.PasswordInput)
